@@ -22,7 +22,7 @@ setMethod(
     sum <- joint_coordinates(x, margin = margin, axes = axes, principal = principal)
     cos2 <- joint_cos2(x, margin = margin, axes = axes)
 
-    data.frame(
+    res <- data.frame(
       coords[, axes, drop = FALSE],
       label = rownames(coords),
       supplementary = coords$.sup,
@@ -32,6 +32,15 @@ setMethod(
       cos2 = cos2,
       row.names = NULL
     )
+
+    if (!methods::is(x, "MultivariateBootstrap")) {
+      ## Reorder
+      ## /!\ see build_results() /!\
+      origin <- get_order(x, margin = margin)
+      res <- res[origin, , drop = FALSE]
+    }
+
+    res
   }
 )
 
