@@ -1,11 +1,10 @@
-if (at_home()) {
+if (at_home() && Sys.info()["sysname"] == "Linux") {
   source("helpers.R")
   using("tinysnapshot")
   options(tinysnapshot_device = "svglite")
   options(tinysnapshot_height = 7) # inches
   options(tinysnapshot_width = 7)
   options(tinysnapshot_tol = 200) # pixels
-  options(tinysnapshot_os = "Linux")
 
   data("colours")
 
